@@ -11,13 +11,11 @@ use warnings;
 
 package WaitReSS::App::Command::new;
 {
-  $WaitReSS::App::Command::new::VERSION = '0.001';
+  $WaitReSS::App::Command::new::VERSION = '0.002';
 }
 # ABSTRACT: Register a new feed
 
 use WaitReSS::App -command;
-use WaitReSS::Collection;
-use WaitReSS::Feed;
 
 
 # -- public methods
@@ -33,13 +31,6 @@ sub opt_spec {
     );
 }
 
-sub execute {
-    my ($self, $opts, $args) = @_;
-    $self->initialize($opts);
-
-    my $url = shift @$args;
-    WaitReSS::Collection->new->register( $url );
-}
 
 1;
 
@@ -53,7 +44,7 @@ WaitReSS::App::Command::new - Register a new feed
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 DESCRIPTION
 
